{% comment %}
 Separated out of results.html to prevent invalid references from crashing the entire
 references listing. (issue #1805)

 If an error is raised inside a template include, the error is caught by the
 calling {% include %} tag and the contents blanked out.

 This behaviour caused a confusing error on the references listing view where it
 would go blank if one of the references was invalid.

 Separating the refereence rendering code into this file allows us to limit Django's
 crash/blanking behaviour to a single reference so the listing can still be used when
 the issue occurs.
{% endcomment %}

<div class="image">{{ reference.slug }}</div>
