# Generated by Django 2.1.4 on 2019-04-16 14:07

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_references', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='reference',
            name='bibjson',
            field=jsonfield.fields.JSONField(default=dict),
        ),
    ]
