{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Add a reference" %}{% endblock %}

{% block content %}
    {% trans "Add reference" as add_str %}
    {% include "wagtailadmin/shared/header.html" with title=add_str icon="list-ol" %}

    <div class="nice-padding">
        <form action="{% url 'wagtailreferences:add' %}" method="POST" enctype="multipart/form-data" novalidate>
            {% csrf_token %}
            <ul class="fields">
                {% for field in form %}
                    {% if field.is_hidden %}
                        {{ field }}
                    {% else %}
                        {% include "wagtailadmin/shared/field_as_li.html" with field=field %}
                    {% endif %}
                {% endfor %}
                <li><input type="submit" value="{% trans 'Save' %}" class="button" /></li>
            </ul>
        </form>
    </div>
{% endblock %}
