

# A series of example bibtex entries for use in testing of this and third party libraries using wagtail_references.
# These examples were exported from Mendeley Desktop (then internal/nonpublic items anonymised).

article1 = """@article{Clark2017a,
author = {Clark, Thomas and Lueck, Rolf G. and Hay, Alex E. and Davey, Thomas and Stern, Peter and Horwitz, Rachel},
journal = {Proc. of the 12th European Wave and Tidal Energy Conference},
pages = {7},
title = {{InSTREAM : Measurement , Characterisation and Simulation of Turbulence from Test Tank to Ocean .}},
year = {2017}
}
"""

article2 = """@article{Shives2011,
abstract = {ABSTRACT:This paper presents a blah blah blah... },
author = {Shives, Michael and Crawford, Curran},
file = {:Users/me/Shives, Crawford - 2011 - Ducted Turbine Blade Optimization Using Numerical Simulation.pdf:pdf},
isbn = {9781880653968},
issn = {10986189},
journal = {Proceedings of the International Offshore and Polar Engineering Conference},
keywords = {blade,computational fluid dynamics,diffuser augmented turbine,element,tidal turbine},
pages = {407--413},
title = {{Ducted Turbine Blade Optimization Using Numerical Simulation}},
year = {2011}
}
"""

misc1 = """@misc{ABC0001_1,
author = {Clark, Thomas Henry},
file = {:Volumes/Clark - 2016 - Instrument Testing.pdf:pdf},
institution = {Company Ltd.},
mendeley-groups = {Internal Reports},
title = {{Instrument Testing}},
year = {2016}
}
"""

techreport1 = """@techreport{DataSheet1,
author = {Smith, John},
file = {:Volumes/Smith - Unknown - Data Exchange Cover Sheet(2).pdf:pdf},
institution = {A COMPANY},
mendeley-groups = {Internal Reports},
title = {{Data Exchange Cover Sheet}}
}
"""

techreport2 = """@techreport{KS9b,
author = {Clark, T.H. and Black, K. and Ibrahim, J. and Minns, N. and Fisher, S. and Roc, T. and Hernon, J. and White, R.},
title = {{MRCF-TiME-KS9b Turbulence: Best practices for data processing, classification and blah.}},
year = {2015}
}
"""

phdthesis1 = """@phdthesis{robinson1990,
abstract = {The long history of research into the internal structure of turbulent boundary layers has not blah.},
author = {Robinson, S K},
file = {:Volumes/Robinson - 1991 - The kinematics of turbulent boundary layer structures.pdf:pdf},
keywords = {coherent structures,kinematics,turbulent boundary layer},
mendeley-groups = {Boundary Layers},
number = {103859},
school = {National Aeronautics and Space Administration},
title = {{The kinematics of turbulent boundary layer structures}},
year = {1991}
}
"""

phdthesis2 = """@phdthesis{worthphd,
abstract = {Further understanding blah blah...

blah TPIV software was developed, with a novel approach permitting a significant reduction in blah and

In support of previous investigations similar topology, strain rate alignment, scale-invariance, and blah.},
author = {Worth, Nicholas},
keywords = {Coherent structures,Experimental,Fluid mechanics,Tomographic particle image velocimetry},
mendeley-groups = {Tomographic PIV},
month = {apr},
school = {University Of Cambridge},
title = {{Tomographic PIV measurement of coherent dissipation scale structures}},
url = {http://www.dspace.cam.ac.uk/handle/1810/237242},
year = {2010}
}
"""
